==> jc-1.4.0.tar.gz: gnu/java/awt/peer/gtk/GtkCheckboxGroupPeer.h <==
// public class gnu.java.awt.peer.gtk.GtkCheckboxGroupPeer

// class file dependencies
// @dep_class 46bc065956ff9376 gnu_java_awt_peer_gtk_GtkCheckboxGroupPeer
// @dep_class d6f9e33c09f7be67 gnu_java_awt_peer_gtk_GtkGenericPeer
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header gnu_java_awt_peer_gtk_GtkGenericPeer

#include "gnu/java/awt/peer/gtk/GtkGenericPeer.h"

#ifndef _JC_gnu_java_awt_peer_gtk_GtkCheckboxGroupPeer_H_
#define _JC_gnu_java_awt_peer_gtk_GtkCheckboxGroupPeer_H_

// Forward structure declarations
struct _jc_gnu_java_awt_peer_gtk_GtkCheckboxGroupPeer$object;
struct _jc_gnu_java_awt_peer_gtk_GtkCheckboxPeer$object;
struct _jc_java_awt_CheckboxGroup$object;
struct _jc_java_lang_Class$object;
struct _jc_java_util_WeakHashMap$object;

// Typedefs
typedef struct _jc_gnu_java_awt_peer_gtk_GtkCheckboxGroupPeer$sub_refs	_jc_gnu_java_awt_peer_gtk_GtkCheckboxGroupPeer$sub_refs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkCheckboxGroupPeer$sub_nonrefs	_jc_gnu_java_awt_peer_gtk_GtkCheckboxGroupPeer$sub_nonrefs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkCheckboxGroupPeer$refs	_jc_gnu_java_awt_peer_gtk_GtkCheckboxGroupPeer$refs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkCheckboxGroupPeer$nonrefs	_jc_gnu_java_awt_peer_gtk_GtkCheckboxGroupPeer$nonrefs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkCheckboxGroupPeer$object	_jc_gnu_java_awt_peer_gtk_GtkCheckboxGroupPeer$object;

typedef struct _jc_gnu_java_awt_peer_gtk_GtkCheckboxGroupPeer$fields_struct	_jc_gnu_java_awt_peer_gtk_GtkCheckboxGroupPeer$fields_struct;
typedef const struct _jc_gnu_java_awt_peer_gtk_GtkCheckboxGroupPeer$vmethods	_jc_gnu_java_awt_peer_gtk_GtkCheckboxGroupPeer$vmethods;
typedef const struct _jc_gnu_java_awt_peer_gtk_GtkCheckboxGroupPeer$vtable	_jc_gnu_java_awt_peer_gtk_GtkCheckboxGroupPeer$vtable;
typedef const struct _jc_gnu_java_awt_peer_gtk_GtkCheckboxGroupPeer$vtype	_jc_gnu_java_awt_peer_gtk_GtkCheckboxGroupPeer$vtype;

// Class fields structure
struct _jc_gnu_java_awt_peer_gtk_GtkCheckboxGroupPeer$fields_struct {
	struct _jc_java_util_WeakHashMap$object	*map;
};
extern _jc_gnu_java_awt_peer_gtk_GtkCheckboxGroupPeer$fields_struct _jc_gnu_java_awt_peer_gtk_GtkCheckboxGroupPeer$class_fields;

// Constructors
extern void _jc_gnu_java_awt_peer_gtk_GtkCheckboxGroupPeer$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkCheckboxGroupPeer$object *);

// Virtual methods
extern void _jc_gnu_java_awt_peer_gtk_GtkCheckboxGroupPeer$method$dispose$9d5b5b52b7878138(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkCheckboxGroupPeer$object *);
extern void _jc_gnu_java_awt_peer_gtk_GtkCheckboxGroupPeer$method$finalize$660a5b5b608ff21f(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkCheckboxGroupPeer$object *);
extern void _jc_gnu_java_awt_peer_gtk_GtkCheckboxGroupPeer$method$remove$f5883945246e3fe2(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkCheckboxGroupPeer$object *, struct _jc_gnu_java_awt_peer_gtk_GtkCheckboxPeer$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkCheckboxGroupPeer$method_info$dispose$9d5b5b52b7878138;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkCheckboxGroupPeer$method_info$finalize$660a5b5b608ff21f;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkCheckboxGroupPeer$method_info$remove$f5883945246e3fe2;

// Static methods
extern void _jc_gnu_java_awt_peer_gtk_GtkCheckboxGroupPeer$method$_clinit$a816641e0ba8bfef(_jc_env *);
extern struct _jc_gnu_java_awt_peer_gtk_GtkCheckboxGroupPeer$object *_jc_gnu_java_awt_peer_gtk_GtkCheckboxGroupPeer$method$getCheckboxGroupPeer$2786651bf481f2e3(_jc_env *, struct _jc_java_awt_CheckboxGroup$object *);

// Virtual methods structure
struct _jc_gnu_java_awt_peer_gtk_GtkCheckboxGroupPeer$vmethods {
	void	(*dispose$9d5b5b52b7878138)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkCheckboxGroupPeer$object *);
	void	(*finalize$660a5b5b608ff21f)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkCheckboxGroupPeer$object *);
	void	(*remove$f5883945246e3fe2)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkCheckboxGroupPeer$object *, struct _jc_gnu_java_awt_peer_gtk_GtkCheckboxPeer$object *);
};

// Vtable
struct _jc_gnu_java_awt_peer_gtk_GtkCheckboxGroupPeer$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_awt_peer_gtk_GtkGenericPeer$vmethods	gnu_java_awt_peer_gtk_GtkGenericPeer;
	_jc_gnu_java_awt_peer_gtk_GtkCheckboxGroupPeer$vmethods	gnu_java_awt_peer_gtk_GtkCheckboxGroupPeer;
};

// Vtype
struct _jc_gnu_java_awt_peer_gtk_GtkCheckboxGroupPeer$vtype {
	_jc_type			type;
	_jc_gnu_java_awt_peer_gtk_GtkCheckboxGroupPeer$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_awt_peer_gtk_GtkCheckboxGroupPeer$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_awt_peer_gtk_GtkCheckboxGroupPeer$refs {
    _jc_gnu_java_awt_peer_gtk_GtkCheckboxGroupPeer$sub_refs	gnu_java_awt_peer_gtk_GtkCheckboxGroupPeer;
    _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$sub_refs	gnu_java_awt_peer_gtk_GtkGenericPeer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_awt_peer_gtk_GtkCheckboxGroupPeer$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_awt_peer_gtk_GtkCheckboxGroupPeer$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$sub_nonrefs	gnu_java_awt_peer_gtk_GtkGenericPeer;
    _jc_gnu_java_awt_peer_gtk_GtkCheckboxGroupPeer$sub_nonrefs	gnu_java_awt_peer_gtk_GtkCheckboxGroupPeer;
};

// Object instance structure
struct _jc_gnu_java_awt_peer_gtk_GtkCheckboxGroupPeer$object {
	_jc_gnu_java_awt_peer_gtk_GtkCheckboxGroupPeer$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_awt_peer_gtk_GtkCheckboxGroupPeer$vtype	*vtype;
	_jc_gnu_java_awt_peer_gtk_GtkCheckboxGroupPeer$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_awt_peer_gtk_GtkCheckboxGroupPeer$vtype _jc_gnu_java_awt_peer_gtk_GtkCheckboxGroupPeer$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_awt_peer_gtk_GtkCheckboxGroupPeer, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_awt_peer_gtk_GtkCheckboxGroupPeer$class_object;

#endif	/* _JC_gnu_java_awt_peer_gtk_GtkCheckboxGroupPeer_H_ */

==> jc-1.4.5.tar.gz: gnu/java/awt/peer/gtk/GtkCheckboxGroupPeer.h <==
// public class gnu.java.awt.peer.gtk.GtkCheckboxGroupPeer

// class file dependencies
// @dep_class 46bc065956ff9376 gnu_java_awt_peer_gtk_GtkCheckboxGroupPeer
// @dep_class d6f9e33c09f7be67 gnu_java_awt_peer_gtk_GtkGenericPeer
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header gnu_java_awt_peer_gtk_GtkGenericPeer

#include "gnu/java/awt/peer/gtk/GtkGenericPeer.h"

#ifndef _JC_gnu_java_awt_peer_gtk_GtkCheckboxGroupPeer_H_
#define _JC_gnu_java_awt_peer_gtk_GtkCheckboxGroupPeer_H_

// Forward structure declarations
struct _jc_gnu_java_awt_peer_gtk_GtkCheckboxGroupPeer$object;
struct _jc_gnu_java_awt_peer_gtk_GtkCheckboxPeer$object;
struct _jc_java_awt_CheckboxGroup$object;
struct _jc_java_lang_Class$object;
struct _jc_java_util_WeakHashMap$object;

// Typedefs
typedef struct _jc_gnu_java_awt_peer_gtk_GtkCheckboxGroupPeer$sub_refs	_jc_gnu_java_awt_peer_gtk_GtkCheckboxGroupPeer$sub_refs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkCheckboxGroupPeer$sub_nonrefs	_jc_gnu_java_awt_peer_gtk_GtkCheckboxGroupPeer$sub_nonrefs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkCheckboxGroupPeer$refs	_jc_gnu_java_awt_peer_gtk_GtkCheckboxGroupPeer$refs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkCheckboxGroupPeer$nonrefs	_jc_gnu_java_awt_peer_gtk_GtkCheckboxGroupPeer$nonrefs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkCheckboxGroupPeer$object	_jc_gnu_java_awt_peer_gtk_GtkCheckboxGroupPeer$object;

typedef struct _jc_gnu_java_awt_peer_gtk_GtkCheckboxGroupPeer$fields_struct	_jc_gnu_java_awt_peer_gtk_GtkCheckboxGroupPeer$fields_struct;
typedef const struct _jc_gnu_java_awt_peer_gtk_GtkCheckboxGroupPeer$vmethods	_jc_gnu_java_awt_peer_gtk_GtkCheckboxGroupPeer$vmethods;
typedef const struct _jc_gnu_java_awt_peer_gtk_GtkCheckboxGroupPeer$vtable	_jc_gnu_java_awt_peer_gtk_GtkCheckboxGroupPeer$vtable;
typedef const struct _jc_gnu_java_awt_peer_gtk_GtkCheckboxGroupPeer$vtype	_jc_gnu_java_awt_peer_gtk_GtkCheckboxGroupPeer$vtype;

// Class fields structure
struct _jc_gnu_java_awt_peer_gtk_GtkCheckboxGroupPeer$fields_struct {
	struct _jc_java_util_WeakHashMap$object	*map;
};
extern _jc_gnu_java_awt_peer_gtk_GtkCheckboxGroupPeer$fields_struct _jc_gnu_java_awt_peer_gtk_GtkCheckboxGroupPeer$class_fields;

// Constructors
extern void _jc_gnu_java_awt_peer_gtk_GtkCheckboxGroupPeer$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkCheckboxGroupPeer$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_gnu_java_awt_peer_gtk_GtkCheckboxGroupPeer$method$dispose$9d5b5b52b7878138(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkCheckboxGroupPeer$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_awt_peer_gtk_GtkCheckboxGroupPeer$method$finalize$660a5b5b608ff21f(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkCheckboxGroupPeer$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_awt_peer_gtk_GtkCheckboxGroupPeer$method$remove$f5883945246e3fe2(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkCheckboxGroupPeer$object *, struct _jc_gnu_java_awt_peer_gtk_GtkCheckboxPeer$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkCheckboxGroupPeer$method_info$dispose$9d5b5b52b7878138;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkCheckboxGroupPeer$method_info$finalize$660a5b5b608ff21f;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkCheckboxGroupPeer$method_info$remove$f5883945246e3fe2;

// Static methods
extern void _jc_gnu_java_awt_peer_gtk_GtkCheckboxGroupPeer$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_gnu_java_awt_peer_gtk_GtkCheckboxGroupPeer$object *_jc_gnu_java_awt_peer_gtk_GtkCheckboxGroupPeer$method$getCheckboxGroupPeer$2786651bf481f2e3(_jc_env *, struct _jc_java_awt_CheckboxGroup$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_java_awt_peer_gtk_GtkCheckboxGroupPeer$vmethods {
	void	(*dispose$9d5b5b52b7878138)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkCheckboxGroupPeer$object *) _JC_JCNI_ATTR;
	void	(*finalize$660a5b5b608ff21f)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkCheckboxGroupPeer$object *) _JC_JCNI_ATTR;
	void	(*remove$f5883945246e3fe2)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkCheckboxGroupPeer$object *, struct _jc_gnu_java_awt_peer_gtk_GtkCheckboxPeer$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_awt_peer_gtk_GtkCheckboxGroupPeer$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_awt_peer_gtk_GtkGenericPeer$vmethods	gnu_java_awt_peer_gtk_GtkGenericPeer;
	_jc_gnu_java_awt_peer_gtk_GtkCheckboxGroupPeer$vmethods	gnu_java_awt_peer_gtk_GtkCheckboxGroupPeer;
};

// Vtype
struct _jc_gnu_java_awt_peer_gtk_GtkCheckboxGroupPeer$vtype {
	_jc_type			type;
	_jc_gnu_java_awt_peer_gtk_GtkCheckboxGroupPeer$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_awt_peer_gtk_GtkCheckboxGroupPeer$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_awt_peer_gtk_GtkCheckboxGroupPeer$refs {
    _jc_gnu_java_awt_peer_gtk_GtkCheckboxGroupPeer$sub_refs	gnu_java_awt_peer_gtk_GtkCheckboxGroupPeer;
    _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$sub_refs	gnu_java_awt_peer_gtk_GtkGenericPeer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_awt_peer_gtk_GtkCheckboxGroupPeer$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_awt_peer_gtk_GtkCheckboxGroupPeer$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$sub_nonrefs	gnu_java_awt_peer_gtk_GtkGenericPeer;
    _jc_gnu_java_awt_peer_gtk_GtkCheckboxGroupPeer$sub_nonrefs	gnu_java_awt_peer_gtk_GtkCheckboxGroupPeer;
};

// Object instance structure
struct _jc_gnu_java_awt_peer_gtk_GtkCheckboxGroupPeer$object {
	_jc_gnu_java_awt_peer_gtk_GtkCheckboxGroupPeer$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_awt_peer_gtk_GtkCheckboxGroupPeer$vtype	*vtype;
	_jc_gnu_java_awt_peer_gtk_GtkCheckboxGroupPeer$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_awt_peer_gtk_GtkCheckboxGroupPeer$vtype _jc_gnu_java_awt_peer_gtk_GtkCheckboxGroupPeer$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_awt_peer_gtk_GtkCheckboxGroupPeer, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_awt_peer_gtk_GtkCheckboxGroupPeer$class_object;

#endif	/* _JC_gnu_java_awt_peer_gtk_GtkCheckboxGroupPeer_H_ */
